@@ -4,10 +4,9 @@
 #include "module.h"
 
 
-#define MODULE_NOISE2_WIDTH                90
 #define MODULE_NOISE2_HEIGHT               75
 
-enum Noises {WHITE,RAND,PINK};
+enum Noises {WHITE,RAND,PINK,PULSETRAIN};
 class M_noise2 : public Module
 {
     Q_OBJECT
@@ -16,11 +15,11 @@ class M_noise2 : public Module
     unsigned int count;
     float rate, level;
     float buf[3], r;
-    Port *port_white, *port_pink, *port_random;
+    Port *port_white, *port_pink, *port_random, *port_pulsetrain;
     float randmax;
 
   public:
-    M_noise2(QWidget* parent=0);
+    M_noise2(QWidget* parent=0, int id = 0);
 
     void generateCycle();
 };
