@@ -1,6 +1,7 @@
 #include <QFileDialog>
 #include <QMessageBox>
 #include <QMenuBar>
+#include <QSettings>
 #include <QScrollArea>
 
 #include "aboutdialog.h"
@@ -40,19 +41,25 @@ int MainWindow::pipeFd[2];
 nsm_client_t *MainWindow::nsm = 0;
 #endif
 
-MainWindow::MainWindow(const ModularSynthOptions& mso)
+MainWindow::MainWindow(const ModularSynthOptions& mso): QMainWindow(),
+    restoregeometry(true),
+    hiderecentfiles(false),
+    rcFd(mso.rcFd),
+    fileName(""),
+    prefDialog(NULL),
+    synthoptions(&mso)
 {
     /*make sure the window destructor is called on program exit*/
     setAttribute(Qt::WA_DeleteOnClose);
     setWindowIcon(QPixmap(ams_32_xpm));
     setObjectName("MainWindow");
-    fileName = "";
-    restoregeometry = true;
-    hiderecentfiles = false;
-    prefDialog = NULL;
     resize(DEFAULT_WIDTH, DEFAULT_HEIGHT);
-    rcFd = mso.rcFd;
-    synthoptions = &mso;
+
+    /*clear global filedialog settings to avoid cross application
+      history spying*/
+    QSettings settings(QSettings::UserScope, "Trolltech");
+    settings.beginGroup("Qt");
+    settings.remove("filedialog");
 
     /*init synthesizer*/
     modularSynth = new ModularSynth(this, mso);
@@ -194,7 +201,8 @@ MainWindow::MainWindow(const ModularSynthOptions& mso)
             modularSynth, SLOT(newM_vocoder()));
 
     /*Time Modifiers submenu*/
-    QMenu *newModuleTimeModifiers = newModulePopup->addMenu(tr("&Time modifiers"));
+    QMenu *newModuleTimeModifiers = newModulePopup->addMenu(
+            tr("&Time modifiers"));
     newModuleTimeModifiers->addAction(tr("&Sample && Hold"),
             modularSynth, SLOT(newM_sh()));
     newModuleTimeModifiers->addAction(tr("&Delay"),
@@ -290,7 +298,8 @@ MainWindow::MainWindow(const ModularSynthOptions& mso)
     newModuleCvOps->addAction(tr("&Hysteresis"),
             modularSynth, SLOT(newM_hysteresis()));
 
-    newModulePopup->addAction(tr("Co&mment"), modularSynth, SLOT(new_textEdit()));
+    newModulePopup->addAction(tr("Co&mment"), modularSynth,
+            SLOT(new_textEdit()));
 
     modulePopup->addAction(tr("&Show LADSPA Browser..."), modularSynth,
             SLOT(displayLadspaPlugins()));
